#' @keywords internal
#' @import dplyr glue ggplot2 gt htmltools paletteer rlang scales
#' @importFrom fontawesome fa
"_PACKAGE"

utils::globalVariables(
  c(
    ".",
    "var", "type", "text", "cmark_rules", "rtf_wrap",
    "Var1", "rtf_escape_unicode", "value", "median", "sd",
    "name", "Mean", "SD", "n_missing", "name", "vals", "x",
    "z_r_group_rows", "group_id", "rownum_i", "group_id", "gt_row_grps",
    "row_id", "DUPE_COLUMN_PLT"
  )
)

## usethis namespace: start
## usethis namespace: end
NULL
